import * as THREE from 'three';
import * as Main from './main.js'
import * as Utils from './utils.js';

/**
 * I moved all the scene geometry creating functions here.
 * Feel free to replace the functions (geometry) here with your own functions (geometry).
 */

/** 
 * Creates an hangar
 */
export function createHangar() {
	var hangar = new THREE.Object3D();
	hangar.name = 'hangar';
	var halfPi = Math.PI / 2;
	
	var leftWall = createWall(0x555555);
	leftWall.position.set(-10, 0, 0);
	leftWall.rotation.set(0, halfPi, 0);
	hangar.add(leftWall);
	
	var rightWall = createWall(0x333333);
	rightWall.position.set(10, 0, 0);
	rightWall.rotation.set(0, -halfPi, 0);
	hangar.add(rightWall);
	
	var backWall = createWall(0x444444);
	backWall.position.set(0, 0, -10);
	hangar.add(backWall);
	
	var ceiling = createWall(0x111111);
	ceiling.position.set(0, 10, 0);
	ceiling.rotation.set(halfPi, 0, 0);
	hangar.add(ceiling);
	
	var floor = createWall(0x222222);
	floor.position.set(0, -10, 0);
	floor.rotation.set(-halfPi, 0, 0);
	floor.name = 'floor';
	hangar.add(floor);
	
	return hangar;
}

/**
 * Create the chopper.
 */
export function createChopper() {
	var chopper = new THREE.Object3D();
	chopper.position.set(0, -8, 0);
	
	var body = createSphere(0xccccee);
	body.scale.set(3, 1, 1);
	chopper.add(body);
	
	var blades = new THREE.Object3D();
	blades.name = 'blades';
	var blade1 = createCube(0xcceecc);
	blade1.position.set(2.7, 1.2, 0);
	blade1.scale.set(2.4, 0.1, 0.4);
	blade1.rotation.set(0, Utils.toRad(180), 0);
	
	blades.add(blade1);
	
	var blade2 = createCube(0xcceecc);
	blade2.scale.set(2.4, 0.1, 0.4);
	blade2.position.set(-2.7, 1.2, 0);
	blades.add(blade2);
	
	chopper.add(blades);
	
	return chopper;
}

function createWall(colorCode) {
	var geometry = new THREE.PlaneGeometry(20, 20, 1);
	var color = new THREE.Color(colorCode);
	var material = Main.createShaderMaterial(color);
	var wall = new THREE.Mesh(geometry, material);
	
	return wall;
}

function createCube(colorCode) {
	var geometry = new THREE.BoxGeometry(2, 2, 2);
	var color = new THREE.Color(colorCode);
	var material = Main.createShaderMaterial(color);
	var cube = new THREE.Mesh(geometry, material);
	
	return cube;
}

function createSphere(colorCode) {
	var geometry = new THREE.SphereGeometry(1, 6, 6);
	var color = new THREE.Color(colorCode);
	var material = Main.createShaderMaterial(color);
	var sphere = new THREE.Mesh(geometry, material);
	
	return sphere;
}